---
title: '홈(대시보드) '
category: 관리자콘솔 (관리자콘솔 사용 가이드) > 홈(대시보드) > 홈(대시보드)
seo:
  title: 홈(대시보드) 가이드
  description: >-
    관리자콘솔 내 대시보드를 소개합니다. 날짜, 주요 공지 알림, 결제내역 조회일자, 거래액 집계데이터, 테스트데이터, 순거래액 랭크 등
    다양한 기능들을 제공하고 있습니다. 전자결제 신청을 위한 경로 안내도 확인해보세요.
  keywords:
    - 대시보드
    - 홈
    - 관리자콘솔
    - 포트원
tags:
  - 공통
  - 관리자콘솔
pgCompanies:
  - 공통
searchTags:
  - 대시보드
  - 관리자콘솔
---

### **홈**



##### **1. 결제내역 조회일자**

- 조회일자(달력)에 따라 결제대시보드 확인이 가능하며, 6개월/1개월/1주로 간편하게 일자 조절이 가능합니다.

##### **2. 일자표기**

- 조회하시는 년도/월/일/요일 이 표기됩니다.

##### **3. 테스트 데이터**

- 대시보드를 임시 데이터로 확인해보실 수 있습니다. \
  (테스트용 상점정보로 결제된 내역이 아닌, 더미데이터 입니다.)

##### **4. 거래액 집계데이터**

- 거래액 : 결제완료 된 적 있는 모든 금액 (결제완료+결제취소 금액 합산)
- 순거래액 : 거래액-거래취소액
- 거래취소액 : 결제완료 후 취소한 금액 (전액취소+부분취소)

##### **5. 거래액 그래프**

- 일간, 시간별 거래액을 그래프 형식으로 확인할 수 있습니다.

##### **6. 순 거래액 TOP5**

- 결제가 많이 발생한 결제수단 TOP5을 확인할 수 있습니다.



##### **7. 공지사항**

- 포트원의 공지사항을 실시간으로 확인할 수 있습니다.
- 모든 공지사항을 확인하시려면 우측 더보기를 클릭해주세요.

##### **8. 새소식**

- 포트원의 새로운 소식을 빠르게 확인하실 수 있습니다.
- 모든 새소식을 확인하시려면 우측 더보기를 클릭해주세요 ([포트원 블로그 ↗](https://blog.portone.io/)  로 이동됩니다.)

##### **9. FAQ**

- 포트원의 주요 FAQ TOP5를 확인하실 수 있습니다.
- 모든 FAQ를 확인하시려면 우측 더보기를 클릭해주세요.

##### **10. 가이드**

- 포트원 서비스를 이용하실 때 필요하신 가이드를 제공드립니다.

### **전자결제 신청 ⚡**

- 전자결제 신청을 위한 경로입니다. 자세한 전자결제 신청 방법은 아래를 클릭하여 확인해주세요.



<Callout title="전자결제 신청방법 보러가기 ↗" icon="" />
